birdears.questions package
==========================

.. automodule:: birdears.questions
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

birdears.questions.harmonicinterval module
------------------------------------------

.. automodule:: birdears.questions.harmonicinterval
   :members:
   :undoc-members:
   :show-inheritance:

birdears.questions.instrumentaldictation module
-----------------------------------------------

.. automodule:: birdears.questions.instrumentaldictation
   :members:
   :undoc-members:
   :show-inheritance:

birdears.questions.melodicdictation module
------------------------------------------

.. automodule:: birdears.questions.melodicdictation
   :members:
   :undoc-members:
   :show-inheritance:

birdears.questions.melodicinterval module
-----------------------------------------

.. automodule:: birdears.questions.melodicinterval
   :members:
   :undoc-members:
   :show-inheritance:

birdears.questions.notename module
----------------------------------

.. automodule:: birdears.questions.notename
   :members:
   :undoc-members:
   :show-inheritance:
